pub struct Compactor { /* private fields */ }Expand description
Background compaction handle.
Implementations
Sourceimpl Compactor
impl Compactor
Sourcepub fn start(
compact_fn: impl Fn() -> DbResult<usize> + Send + 'static,
interval: Duration,
) -> Self
pub fn start( compact_fn: impl Fn() -> DbResult<usize> + Send + 'static, interval: Duration, ) -> Self
Start a background compaction thread with its own shutdown signal.
Sourcepub fn start_with_signal(
compact_fn: impl Fn() -> DbResult<usize> + Send + 'static,
interval: Duration,
signal: ShutdownSignal,
) -> Self
pub fn start_with_signal( compact_fn: impl Fn() -> DbResult<usize> + Send + 'static, interval: Duration, signal: ShutdownSignal, ) -> Self
Start a background compaction thread controlled by an external shutdown signal. When the signal fires the thread wakes up immediately instead of waiting for the full sleep interval.
pub fn stop(&mut self)